# Hooks API

Hook system for intercepting and managing model activations during inference.

## Core Hook Classes

::: mi_crow.hooks.hook.Hook

::: mi_crow.hooks.detector.Detector

::: mi_crow.hooks.controller.Controller

## Implementations

::: mi_crow.hooks.implementations.layer_activation_detector.LayerActivationDetector

::: mi_crow.hooks.implementations.model_input_detector.ModelInputDetector

::: mi_crow.hooks.implementations.model_output_detector.ModelOutputDetector

::: mi_crow.hooks.implementations.function_controller.FunctionController

## Utilities

::: mi_crow.hooks.utils

